# jaxctx
JAX Context for memoizationg collections of parameters, and handling sequences of random keys.
Based loosely on things like haiku, and flax, but not deep learning specific. No support for lifting things like 
scan, etc. You must build these things on top of this if you want them.
